@@ -485,10 +485,13 @@ def createDjangoProject(name, database, design):
         if design == "logico":
             url = "https://gitlab.com/AlejandroBarcenas/template-django-logic.git"
             name_git = "template-django-logic"
-            message, result = createDjango(name=name,
-                                           database=database,
-                                           path=os.getcwd(),
-                                           url=url,
-                                           name_git=name_git)
+        elif design == "fisico":
+            url = "https://gitlab.com/AlejandroBarcenas/template-django-physic.git"
+            name_git = "template-django-physic"
+        message, result = createDjango(name=name,
+                                       database=database,
+                                       path=os.getcwd(),
+                                       url=url,
+                                       name_git=name_git)
 
         return message, result
